#!/usr/bin/env bash
if [[ ${1#lib} == $1 ]]
	then LIBNAME=lib${1}
	else LIBNAME=$1
fi
TRLIBNAME=$(printf $LIBNAME | tr - _)
cat > $1/src/Makefile.am <<EOF
lib_LTLIBRARIES = ${LIBNAME}.la
include_HEADERS = lib.h

${TRLIBNAME}_la_SOURCES = lib.h lib.c
${TRLIBNAME}_la_CPPFLAGS = -I. \$(DEPS_CFLAGS)
${TRLIBNAME}_la_LIBADD = \$(DEPS_LIBS)
EOF
